Struct CancellationToken
pub struct CancellationToken {
value: Arc<AtomicBool>,
}Available on crate feature
rdf only.Expand description
A token that can be used to mark something as canceled.
To cancel run CancellationToken::cancel and to check if the token is canceled run CancellationToken::is_cancelled.
Fields
value: Arc<AtomicBool>Implementations
impl CancellationToken
impl CancellationToken