Struct Update
pub struct Update {
pub(super) inner: Update,
pub(super) using_datasets: Vec<Option<QueryDatasetSpecification>>,
}๐Deprecated since 0.5.0:
Use SparqlEvaluator instead to parse the update with options or directly the spargebra::Update type
Available on crate feature
rdf only.Expand description
A parsed SPARQL update.
use oxigraph::sparql::Update;
let update_str = "CLEAR ALL ;";
let update = Update::parse(update_str, None)?;
assert_eq!(update.to_string().trim(), update_str);Fields
inner: Update๐Deprecated since 0.5.0:
Use SparqlEvaluator instead to parse the update with options or directly the spargebra::Update type
using_datasets: Vec<Option<QueryDatasetSpecification>>๐Deprecated since 0.5.0:
Use SparqlEvaluator instead to parse the update with options or directly the spargebra::Update type
Implementations
impl Update
impl Update
pub fn parse(
update: &str,
base_iri: Option<&str>,
) -> Result<Update, SparqlSyntaxError>
pub fn parse( update: &str, base_iri: Option<&str>, ) -> Result<Update, SparqlSyntaxError>
Parses a SPARQL update with an optional base IRI to resolve relative IRIs in the query.
pub fn using_datasets(&self) -> impl Iterator<Item = &QueryDatasetSpecification>
pub fn using_datasets(&self) -> impl Iterator<Item = &QueryDatasetSpecification>
pub fn using_datasets_mut(
&mut self,
) -> impl Iterator<Item = &mut QueryDatasetSpecification>
pub fn using_datasets_mut( &mut self, ) -> impl Iterator<Item = &mut QueryDatasetSpecification>