Enum QueryEvaluationError
#[non_exhaustive]pub enum QueryEvaluationError {
Dataset(Box<dyn Error + Sync + Send>),
Service(Box<dyn Error + Sync + Send>),
NotExistingSubstitutedVariable(Variable),
UnexpectedDefaultGraph,
UnsupportedCustomFunction(NamedNode),
UnsupportedCustomFunctionArity {
name: NamedNode,
expected: RangeInclusive<usize>,
actual: usize,
},
UnboundService,
InvalidServiceName(Term),
UnsupportedService(NamedNode),
InvalidStorageTripleTerm,
Cancelled,
}Available on crate feature
rdf only.Expand description
A SPARQL evaluation error
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Dataset(Box<dyn Error + Sync + Send>)
Error from the underlying RDF dataset
Service(Box<dyn Error + Sync + Send>)
Error during SERVICE evaluation
NotExistingSubstitutedVariable(Variable)
If a variable present in the given initial substitution is not present in the SELECT part of the query
UnexpectedDefaultGraph
Error if the dataset returns the default graph even if a named graph is expected
UnsupportedCustomFunction(NamedNode)
The given custom function is not supported
UnsupportedCustomFunctionArity
The given custom function arity is not supported
UnboundService
The variable storing the SERVICE name is unbound
InvalidServiceName(Term)
Invalid service name
UnsupportedService(NamedNode)
The given SERVICE is not supported
InvalidStorageTripleTerm
Available on crate feature
sparql-12 only.Cancelled