Struct PreparedSparqlQuery
pub struct PreparedSparqlQuery {
evaluator: QueryEvaluator,
query: Query,
dataset: QueryDatasetSpecification,
substitutions: HashMap<Variable, Term>,
}Available on crate feature
rdf only.Expand description
A prepared SPARQL query.
Allows customizing things like the evaluation dataset and substituting variables.
Usage example:
use oxigraph::model::{Literal, Variable};
use oxigraph::sparql::{QueryResults, SparqlEvaluator};
use oxigraph::store::Store;
let prepared_query = SparqlEvaluator::new()
.parse_query("SELECT ?v WHERE {}")?
.substitute_variable(Variable::new("v")?, Literal::from(1));
if let QueryResults::Solutions(mut solutions) =
prepared_query.on_store(&Store::new()?).execute()?
{
assert_eq!(
solutions.next().unwrap()?.get("v"),
Some(&Literal::from(1).into())
);
}Fields
evaluator: QueryEvaluatorquery: Querydataset: QueryDatasetSpecificationsubstitutions: HashMap<Variable, Term>Implementations
impl PreparedSparqlQuery
impl PreparedSparqlQuery
pub fn substitute_variable(
self,
variable: impl Into<Variable>,
term: impl Into<Term>,
) -> PreparedSparqlQuery
pub fn substitute_variable( self, variable: impl Into<Variable>, term: impl Into<Term>, ) -> PreparedSparqlQuery
Substitute a variable with a given RDF term in the SPARQL query.
Usage example:
use oxigraph::model::{Literal, Variable};
use oxigraph::sparql::{QueryResults, SparqlEvaluator};
use oxigraph::store::Store;
let prepared_query = SparqlEvaluator::new()
.parse_query("SELECT ?v WHERE {}")?
.substitute_variable(Variable::new("v")?, Literal::from(1));
if let QueryResults::Solutions(mut solutions) =
prepared_query.on_store(&Store::new()?).execute()?
{
assert_eq!(
solutions.next().unwrap()?.get("v"),
Some(&Literal::from(1).into())
);
}pub fn dataset(&self) -> &QueryDatasetSpecification
pub fn dataset(&self) -> &QueryDatasetSpecification
Returns the query dataset specification of this prepared query.
pub fn dataset_mut(&mut self) -> &mut QueryDatasetSpecification
pub fn dataset_mut(&mut self) -> &mut QueryDatasetSpecification
Returns the query dataset specification of this prepared query.
pub fn on_store(self, store: &Store) -> BoundPreparedSparqlQuery<'static>
pub fn on_store(self, store: &Store) -> BoundPreparedSparqlQuery<'static>
Bind the prepared query to the [Store] it should be evaluated on.
pub fn on_transaction<'b>(
self,
transaction: &'b Transaction<'_>,
) -> BoundPreparedSparqlQuery<'b>
pub fn on_transaction<'b>( self, transaction: &'b Transaction<'_>, ) -> BoundPreparedSparqlQuery<'b>
Bind the prepared query to the [Transaction] it should be evaluated on.
pub fn on_queryable_dataset<'a, D>(
self,
queryable_dataset: D,
) -> BoundPreparedSparqlQuery<'a, D>where
D: QueryableDataset<'a>,
pub fn on_queryable_dataset<'a, D>(
self,
queryable_dataset: D,
) -> BoundPreparedSparqlQuery<'a, D>where
D: QueryableDataset<'a>,
Bind the prepared query to the [QueryableDataset] it should be evaluated on.