Struct Query
pub struct Query {
pub(super) inner: Query,
pub(super) dataset: QueryDatasetSpecification,
}👎Deprecated since 0.5.0: Use SparqlEvaluator instead to parse the query with options or directly the spargebra::Query type
Available on crate feature
rdf only.Expand description
A parsed SPARQL query.
use oxigraph::model::NamedNode;
use oxigraph::sparql::Query;
let query_str = "SELECT ?s ?p ?o WHERE { ?s ?p ?o . }";
let mut query = Query::parse(query_str, None)?;
assert_eq!(query.to_string(), query_str);
// We edit the query dataset specification
let default = vec![NamedNode::new("http://example.com")?.into()];
query.dataset_mut().set_default_graph(default.clone());
assert_eq!(
query.dataset().default_graph_graphs(),
Some(default.as_slice())
);Fields
inner: Query👎Deprecated since 0.5.0: Use SparqlEvaluator instead to parse the query with options or directly the spargebra::Query type
dataset: QueryDatasetSpecification👎Deprecated since 0.5.0: Use SparqlEvaluator instead to parse the query with options or directly the spargebra::Query type
Implementations
impl Query
impl Query
pub fn parse(
query: &str,
base_iri: Option<&str>,
) -> Result<Query, SparqlSyntaxError>
pub fn parse( query: &str, base_iri: Option<&str>, ) -> Result<Query, SparqlSyntaxError>
Parses a SPARQL query with an optional base IRI to resolve relative IRIs in the query.
pub fn dataset(&self) -> &QueryDatasetSpecification
pub fn dataset(&self) -> &QueryDatasetSpecification
Returns the query dataset specification
pub fn dataset_mut(&mut self) -> &mut QueryDatasetSpecification
pub fn dataset_mut(&mut self) -> &mut QueryDatasetSpecification
Returns the query dataset specification